DirectedEdgeIndex

Struct DirectedEdgeIndex 

pub struct DirectedEdgeIndex(/* private fields */);
Represents a single directed edge between two cells (an “origin” cell and a neighboring “destination” cell).

The index is encoded on 64-bit with the following bit layout:

 ┏━┳━━━┳━━━┳━━━━━━━━━━━━━━━━━━━━━━┈┈┈┈┈┈┈┈━━━━━━━┓
 ┃U┃ M ┃ E ┃                O                    ┃
 ┗━┻━━━┻━━━┻━━━━━━━━━━━━━━━━━━━━━━┈┈┈┈┈┈┈┈━━━━━━━┛
64 63 59   56                                    0

Where:

  • U is an unused reserved bit, always set to 0 (bit 63).
  • M is the index mode, always set to 2, coded on 4 bits (59-62).
  • E is the edge of the origin cell, in [1; 6], coded on 3 bits (56-58).
  • O is the origin cell index, coded on 56 bits (0-55).

References:

Implementations

Source

impl DirectedEdgeIndex

pub fn reverse(self) -> Self

Returns the directed edge with origin and destination cells reversed.

pub fn edge(self) -> Edge

Returns the cell edge.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
assert_eq!(index.edge(), h3o::Edge::try_from(3)?);
pub fn origin(self) -> CellIndex

Returns the origin hexagon from the directed edge index.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
assert_eq!(index.origin(), h3o::CellIndex::try_from(0x8a194e699ab7fff)?);
pub fn destination(self) -> CellIndex

Returns the destination hexagon from the directed edge index.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a1_94e6_99ab_7fff)?;
assert_eq!(index.destination(), h3o::CellIndex::try_from(0x8a194e699a97fff)?);
pub fn cells(self) -> (CellIndex, CellIndex)

Returns the (origin, destination) pair of cell index for this edge.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a1_94e6_99ab_7fff)?;
assert_eq!(index.cells(), (
    h3o::CellIndex::try_from(0x8a194e699ab7fff)?,
    h3o::CellIndex::try_from(0x8a194e699a97fff)?,
));
pub fn boundary(self) -> Boundary

Returns the coordinates defining the directed edge.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
let boundary = index.boundary();
pub fn length_rads(self) -> f64

Computes the length of this directed edge, in radians.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
float_eq::assert_float_eq!(
    index.length_rads(),
    1.1795418098325597e-5,
    abs <= 1e-11
);
pub fn length_km(self) -> f64

Computes the length of this directed edge, in kilometers.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
float_eq::assert_float_eq!(
    index.length_km(),
    0.07514869340636812,
    abs <= 1e-11
);
pub fn length_m(self) -> f64

Computes the length of this directed edge, in meters.

Example
let index = h3o::DirectedEdgeIndex::try_from(0x13a194e699ab7fff)?;
float_eq::assert_float_eq!(
    index.length_m(),
    75.14869340636812,
    abs <= 1e-8
);